require 'spec_helper'

describe Todo do

  describe "when created" do
    it "sets done to false per default" do
      Todo.create(title: "Foo").done.should == false
    end
  end

  describe "scopes for done and undone" do
    let( :undone ) {  FactoryGirl.create(:todo, done: false) }
    let( :done ) {  FactoryGirl.create(:todo, done: true) }

    before(:each) { undone; done }

    describe "Todo#done" do
      it "returns todos marked as done " do
        Todo.done.should include(done)
      end

      it "does not return todos which are undone" do
        Todo.done.should_not include(undone)
      end
    end

    describe "Todo#undone" do
      it "does not return todos marked as done " do
        Todo.undone.should_not include(done)
      end

      it "returns todos which are undone" do
        Todo.undone.should include(undone)
      end
    end
  end
end
